@@ -29,7 +29,7 @@
 
 #include <LXQt/Globals>
 
-AutoStartEdit::AutoStartEdit(const QString& name, const QString& command, bool needTray, QWidget *parent) :
+AutoStartEdit::AutoStartEdit(const QString& name, const QString& command, bool needTray, bool x11Only, QWidget *parent) :
     QDialog(parent),
     ui(new Ui::AutoStartEdit)
 {
@@ -38,24 +38,30 @@ AutoStartEdit::AutoStartEdit(const QString& name, const QString& command, bool n
     ui->nameEdit->setText(name);
     ui->commandEdit->setText(command);
     ui->trayCheckBox->setChecked(needTray);
+    ui->x11CheckBox->setChecked(x11Only);
     connect(ui->browseButton, &QPushButton::clicked, this, &AutoStartEdit::browse);
 }
 
-QString AutoStartEdit::name()
+QString AutoStartEdit::name() const
 {
     return ui->nameEdit->text();
 }
 
-QString AutoStartEdit::command()
+QString AutoStartEdit::command() const
 {
     return ui->commandEdit->text();
 }
 
-bool AutoStartEdit::needTray()
+bool AutoStartEdit::needTray() const
 {
     return ui->trayCheckBox->isChecked();
 }
 
+bool AutoStartEdit::x11Only() const
+{
+    return ui->x11CheckBox->isChecked();
+}
+
 void AutoStartEdit::browse()
 {
     QString filePath = QFileDialog::getOpenFileName(this, tr("Select Application"), QSL("/usr/bin/"));
